# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:
let
    unstable = import <unstable> {};
in {

programs.nix-ld.enable = true;
  imports = [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
      ./ledger.nix
   ];

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  #power
  services.logind.lidSwitch = "ignore";
  services.autorandr.enable = true;

  #networking.hostName = "nixos"; # Define your hostname.
  networking.networkmanager.enable = true;


  #networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.

  # Set your time zone.
  time.timeZone = "Europe/Paris";

  # The global useDHCP flag is deprecated, therefore explicitly set to false here.
  # Per-interface useDHCP will be mandatory in the future, so this generated config
  # replicates the default behaviour.
  networking.useDHCP = false;
  networking.interfaces.enp3s0.useDHCP = true;
  #networksering.interfaces.wlp2s0.useDHCP = true;

  # Configure network proxy if necessary
  # networking.proxy.default = "http://user:password@proxy:port/";
  # networking.proxy.noProxy = "127.0.0.1,localhost,internal.domain";

  # Select internationalisation properties.
  # i18n.defaultLocale = "en_US.UTF-8";
  # console = {
  #   font = "Lat2-Terminus16";
  #   keyMap = "us";
  # };



  # Enable the X11 windowing system.
  services.xserver = {
	enable = true;
	# Configure keymap in X11
	layout = "fr";
	xkbOptions = "eurosign:e";
	displayManager.sessionCommands = ''
		${pkgs.bspwm}/bin/bspc wm -r
		source $HOME/.config/bspwm/bspwmrc
	'';		

	# Keyboard reactivity	
	autoRepeatDelay = 200;
	autoRepeatInterval = 35;		
		
		
	windowManager.bspwm.enable = true;
	#desktopManager.xterm.enable = true;
	
	# gnome
	#displayManager.gdm.enable = true;
	#desktopManager.gnome.enable = true;	

	displayManager.defaultSession = "none+bspwm";
	#displayManager.startx.enable = true;
	libinput = {

  		# Enable touchpad support (enabled default in most desktopManager).
		enable = true;
		touchpad.accelSpeed = "0.155";
	};
  };
  virtualisation.docker.enable = true;  

  # Enable CUPS to print documents.
  # services.printing.enable = true;

  # Enable sound.
  sound.enable = true;
  hardware.pulseaudio.enable = true;

  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.grimhilt = {
    isNormalUser = true;
    home = "/home/grimhilt";
    extraGroups = [ "audio" "wheel" "networkmanager" "video" "docker" "plugdev"];
  };
 
#  fileSystems."/home/grimhilt/My" = {
 #   device = "/dev/sdb2";
#  #  fsType = "auto";
   # options = [ "uid=1000" "gid=1000" "dmask=007" "fmask=117" ]; 
# }; 

  # List packages installed in system profile. To search, run:
  # $ nix search wget
   environment.systemPackages = with pkgs; [
    # editors
    vim
    neovim
    vscode

    # system tools
    bspwm
    sxhkd
    alacritty
    zsh
    polybar
    rofi
    brightnessctl
    i3lock-color
    pamixer
    flameshot
    home-manager
    lxappearance

    # browsers
    librewolf
    firefox
    brave
    chromium

    # utils
    dolphin
    git
    ranger
    wget
    zip
    unzip
    calc
    tree
    htop
    putty

    # apps
    element-desktop
    nextcloud-client
    discord
    onlyoffice-bin
    unstable.ledger-live-desktop
    ledger-udev-rules

    # media
    gimp
    gthumb
    feh

    # devs
    python311
    geany
    nasm

    # tmp
    # gsettings-desktop-schemas
  ];

#  environment.gnome.excludePackages = (with pkgs; [
#  	  gnome-photos
#  	  gnome-tour
#  ]) ++ (with pkgs.gnome; [
#  	  cheese # webcam tool
#  	  gnome-music
#  	  gnome-terminal
#  	  gedit # text editor
#  	  epiphany # web browser
#  	  geary # email reader
#  	  evince # document viewer
#  	  gnome-characters
#  	  totem # video player
#  	  tali # poker game
#  	  iagno # go game
#  	  hitori # sudoku game
#  	  atomix # puzzle game
#  ]);
  
  fonts.fonts = [ pkgs.font-awesome ];
  
  nixpkgs.config.allowUnfree = true;
  nix.extraOptions = ''
      experimental-features = nix-command
   '';
  programs.zsh.enable = true;
  users.defaultUserShell = pkgs.zsh;
  programs.zsh.ohMyZsh = {
    enable = true;
    theme = "candy-kingdom";
  };
  # Some programs need SUID wrappers, can be configured further or are
  # started in user sessions.
  # programs.mtr.enable = true;
  # programs.gnupg.agent = {
  #   enable = true;
  #   enableSSHSupport = true;
  # };
  
  # Enable the OpenSSH daemon.
  # services.openssh.enable = true;

  # Open ports in the firewall.
  # networking.firewall.allowedTCPPorts = [ ... ];
  # networking.firewall.allowedUDPPorts = [ ... ];
  # Or disable the firewall altogether.
  # networking.firewall.enable = false;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "21.11"; # Did you read the comment?

}

